@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,17 +8,17 @@
 
 #include <QComboBox>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveEditorGraphicalModeWidget;
 class SelectMatchTypeComboBox : public QComboBox
 {
     Q_OBJECT
 public:
     explicit SelectMatchTypeComboBox(KSieveUi::SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent = nullptr);
-    ~SelectMatchTypeComboBox();
+    ~SelectMatchTypeComboBox() override;
 
     Q_REQUIRED_RESULT QString code(bool &negative) const;
-    Q_REQUIRED_RESULT bool isNegative() const;
     void setCode(const QString &code, const QString &name, QString &error);
 
     QStringList needRequires() const;
