@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,8 @@
 #define SIEVEACTIONSETFLAGS_H
 
 #include "sieveactionabstractflags.h"
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveActionSetFlags : public SieveActionAbstractFlags
 {
     Q_OBJECT
