@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,7 +8,8 @@
 
 #include <KPIMTextEdit/PlainTextEditor>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class MultiLineEdit : public KPIMTextEdit::PlainTextEditor
 {
     Q_OBJECT
