@@ -1,22 +1,23 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "selectflagswidget.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
 
-#include <QLineEdit>
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
+#include <Libkdepim/LineEditCatchReturnKey>
+#include <QLineEdit>
 
-#include <QPushButton>
+#include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QPointer>
-#include <QDialogButtonBox>
-#include <QVBoxLayout>
+#include <QPushButton>
 #include <QToolButton>
+#include <QVBoxLayout>
 
 using namespace KSieveUi;
 
@@ -25,10 +26,10 @@ SelectFlagsListDialog::SelectFlagsListDialog(QWidget *parent)
     , mListWidget(new SelectFlagsListWidget(this))
 {
     setWindowTitle(i18nc("@title:window", "Flags"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(mListWidget);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -81,7 +82,7 @@ SelectFlagsListWidget::~SelectFlagsListWidget()
 
 void SelectFlagsListWidget::init()
 {
-    QListWidgetItem *item = new QListWidgetItem(i18n("Deleted"), this);
+    auto item = new QListWidgetItem(i18n("Deleted"), this);
     item->setData(FlagsRealName, QStringLiteral("\\\\Deleted"));
     item->setCheckState(Qt::Unchecked);
     item = new QListWidgetItem(i18n("Answered"), this);
@@ -93,8 +94,8 @@ void SelectFlagsListWidget::init()
     item = new QListWidgetItem(i18n("Seen"), this);
     item->setData(FlagsRealName, QStringLiteral("\\\\Seen"));
     item->setCheckState(Qt::Unchecked);
-    //item = new QListWidgetItem(QStringLiteral("\\\\Recent"), this);
-    //item->setCheckState(Qt::Unchecked);
+    // item = new QListWidgetItem(QStringLiteral("\\\\Recent"), this);
+    // item->setCheckState(Qt::Unchecked);
     item = new QListWidgetItem(i18n("Draft"), this);
     item->setData(FlagsRealName, QStringLiteral("\\\\Draft"));
     item->setCheckState(Qt::Unchecked);
@@ -127,14 +128,15 @@ QStringList SelectFlagsListWidget::flags() const
 SelectFlagsWidget::SelectFlagsWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *lay = new QHBoxLayout(this);
+    auto lay = new QHBoxLayout(this);
     lay->setContentsMargins({});
     mEdit = new QLineEdit(this);
+    new KPIM::LineEditCatchReturnKey(mEdit, this);
     mEdit->setReadOnly(true);
     mEdit->setPlaceholderText(i18n("Click on button for selecting flags..."));
     connect(mEdit, &QLineEdit::textChanged, this, &SelectFlagsWidget::valueChanged);
     lay->addWidget(mEdit);
-    auto *selectFlags = new QToolButton(this);
+    auto selectFlags = new QToolButton(this);
     selectFlags->setText(i18n("..."));
     selectFlags->setToolTip(i18n("Select Flags"));
     connect(selectFlags, &QPushButton::clicked, this, &SelectFlagsWidget::slotSelectFlags);
