@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,21 +10,20 @@
 #include <QListWidget>
 class QLineEdit;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SelectFlagsListWidget : public QListWidget
 {
     Q_OBJECT
 public:
     explicit SelectFlagsListWidget(QWidget *parent = nullptr);
-    ~SelectFlagsListWidget();
+    ~SelectFlagsListWidget() override;
 
     void setFlags(const QStringList &list);
     Q_REQUIRED_RESULT QStringList flags() const;
 
 private:
-    enum Type {
-        FlagsRealName = Qt::UserRole + 1
-    };
+    enum Type { FlagsRealName = Qt::UserRole + 1 };
     void init();
 };
 
