@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,10 +8,12 @@
 
 #include <QList>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveCondition;
 class SieveEditorGraphicalModeWidget;
-namespace SieveConditionList {
+namespace SieveConditionList
+{
 Q_REQUIRED_RESULT QList<KSieveUi::SieveCondition *> conditionList(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget);
 }
 }
