@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #include "autocreatescripts/autocreatescriptutil_p.h"
 #include "editor/sieveeditorutil.h"
 #include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QLineEdit>
 
-#include <QWidget>
-#include <QHBoxLayout>
 #include "libksieve_debug.h"
+#include <QHBoxLayout>
+#include <QWidget>
 #include <QXmlStreamReader>
 
 using namespace KSieveUi;
@@ -22,12 +23,13 @@ SieveConditionMailboxExists::SieveConditionMailboxExists(SieveEditorGraphicalMod
 
 QWidget *SieveConditionMailboxExists::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *lay = new QHBoxLayout;
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
     lay->setContentsMargins({});
     w->setLayout(lay);
 
-    auto *edit = new QLineEdit;
+    auto edit = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(edit, w);
     connect(edit, &QLineEdit::textChanged, this, &SieveConditionMailboxExists::valueChanged);
     edit->setClearButtonEnabled(true);
     lay->addWidget(edit);
@@ -61,7 +63,8 @@ QString SieveConditionMailboxExists::serverNeedsCapability() const
 QString SieveConditionMailboxExists::help() const
 {
     return i18n(
-        "The \"mailboxexists\" test is true if all mailboxes listed in the \"mailbox-names\" argument exist in the mailstore, and each allows the user in whose context the Sieve script runs to \"deliver\" messages into it.");
+        "The \"mailboxexists\" test is true if all mailboxes listed in the \"mailbox-names\" argument exist in the mailstore, and each allows the user in "
+        "whose context the Sieve script runs to \"deliver\" messages into it.");
 }
 
 void SieveConditionMailboxExists::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
@@ -71,11 +74,11 @@ void SieveConditionMailboxExists::setParamWidgetValue(QXmlStreamReader &element,
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("str")) {
             const QString tagValue = element.readElementText();
-            auto *edit = w->findChild<QLineEdit *>(QStringLiteral("edit"));
+            auto edit = w->findChild<QLineEdit *>(QStringLiteral("edit"));
             edit->setText(AutoCreateScriptUtil::quoteStr(tagValue));
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
         } else {
