@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,21 +13,21 @@
 
 class QLineEdit;
 class QPushButton;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SelectHeadersWidget : public QListWidget
 {
     Q_OBJECT
 public:
     explicit SelectHeadersWidget(QWidget *parent = nullptr);
-    ~SelectHeadersWidget();
+    ~SelectHeadersWidget() override;
 
     Q_REQUIRED_RESULT QString headers() const;
     void setListHeaders(const QMap<QString, QString> &lst, const QStringList &selectedHeaders);
     void addNewHeader(const QString &header);
+
 private:
-    enum HeaderEnum {
-        HeaderId = Qt::UserRole + 1
-    };
+    enum HeaderEnum { HeaderId = Qt::UserRole + 1 };
 
     void init();
 };
