@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,14 +10,15 @@
 #include <QWidget>
 
 class QSpinBox;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SelectSizeTypeComboBox;
 class SelectSizeWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit SelectSizeWidget(QWidget *parent = nullptr);
-    ~SelectSizeWidget();
+    ~SelectSizeWidget() override;
 
     Q_REQUIRED_RESULT QString code() const;
     void setCode(qlonglong value, const QString &identifier, const QString &name, QString &error);
