@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,15 +7,16 @@
 #ifndef SIEVEEDITORGRAPHICALMODEWIDGETABSTRACT_H
 #define SIEVEEDITORGRAPHICALMODEWIDGETABSTRACT_H
 
-#include <editor/sieveeditorabstractwidget.h>
 #include "ksieveui_private_export.h"
-namespace KSieveUi {
+#include <editor/sieveeditorabstractwidget.h>
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT SieveEditorGraphicalModeWidgetAbstract : public KSieveUi::SieveEditorAbstractWidget
 {
     Q_OBJECT
 public:
     explicit SieveEditorGraphicalModeWidgetAbstract(QWidget *parent);
-    ~SieveEditorGraphicalModeWidgetAbstract();
+    ~SieveEditorGraphicalModeWidgetAbstract() override;
 
     Q_REQUIRED_RESULT virtual QString script(QStringList &requireModules) const = 0;
 
