@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,22 +7,23 @@
 #ifndef SIEVESCRIPTLISTBOX_H
 #define SIEVESCRIPTLISTBOX_H
 
+#include "ksieveui_private_export.h"
 #include <QGroupBox>
 #include <QListWidgetItem>
-#include "ksieveui_private_export.h"
 
 class QListWidget;
 class QPushButton;
 class QXmlStreamReader;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveEditorGraphicalModeWidget;
 class SieveScriptPage;
 class SieveScriptListItem : public QListWidgetItem
 {
 public:
     SieveScriptListItem(const QString &text, QListWidget *parent);
-    ~SieveScriptListItem();
+    ~SieveScriptListItem() override;
 
     void setDescription(const QString &desc);
     Q_REQUIRED_RESULT QString description() const;
@@ -42,7 +43,7 @@ class KSIEVEUI_TESTS_EXPORT SieveScriptListBox : public QGroupBox
     Q_OBJECT
 public:
     explicit SieveScriptListBox(const QString &title, QWidget *parent = nullptr);
-    ~SieveScriptListBox();
+    ~SieveScriptListBox() override;
 
     void setSieveEditorGraphicalModeWidget(SieveEditorGraphicalModeWidget *graphicalModeWidget);
     Q_REQUIRED_RESULT QString generatedScript(QStringList &required) const;
