@@ -1,34 +1,33 @@
 /*
   sievedebugdialog.h
 
-  Copyright (c) 2005 Martijn Klingens <klingens@kde.org>
+  SPDX-FileCopyrightText: 2005 Martijn Klingens <klingens@kde.org>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License,
-  version 2.0, as published by the Free Software Foundation.
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software Foundation,
-  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #ifndef KSIEVE_KSIEVEUI_SIEVEDEBUGDIALOG_H
 #define KSIEVE_KSIEVEUI_SIEVEDEBUGDIALOG_H
 
 #include "ksieveui_export.h"
+#include "util_p.h"
 
+#include <KSyntaxHighlighting/Repository>
 #include <QDialog>
 #include <QUrl>
-#include <KSyntaxHighlighting/Repository>
 
-class QStringList;
+#include <QStringList>
 
-namespace KManageSieve {
+namespace KManageSieve
+{
 class SieveJob;
 }
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveImapPasswordProvider;
 
 /**
@@ -40,7 +39,7 @@ class KSIEVEUI_EXPORT SieveDebugDialog : public QDialog
     Q_OBJECT
 public:
     explicit SieveDebugDialog(SieveImapPasswordProvider *passwordProvider, QWidget *parent = nullptr);
-    ~SieveDebugDialog();
+    ~SieveDebugDialog() override;
 
 Q_SIGNALS:
     void result(bool success);
@@ -53,18 +52,21 @@ private Q_SLOTS:
     void slotDiagNextScript();
 
     void slotShutDownJob();
+
 private:
+    void slotFindAccountInfoFinished(const KSieveUi::Util::AccountInfo &info);
+    void slotFindAccountInfoForScriptFinished(const KSieveUi::Util::AccountInfo &info);
     void writeConfig();
     void readConfig();
-    KManageSieve::SieveJob *mSieveJob;
+    KManageSieve::SieveJob *mSieveJob = nullptr;
     QUrl mUrl;
     KSyntaxHighlighting::Repository mRepo;
 
-    SieveImapPasswordProvider *mPasswordProvider;
-    KPIMTextEdit::PlainTextEditorWidget *mEdit;
+    SieveImapPasswordProvider *const mPasswordProvider;
+    KPIMTextEdit::PlainTextEditorWidget *mEdit = nullptr;
     QStringList mResourceIdentifier;
     QStringList mScriptList;
-    QTimer *mShutDownJob;
+    QTimer *mShutDownJob = nullptr;
 };
 }
 
