@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -20,12 +20,12 @@ SieveInfoDialogTest::SieveInfoDialogTest(QObject *parent)
 void SieveInfoDialogTest::shouldHaveDefaultValues()
 {
     KSieveUi::SieveInfoDialog dlg;
-    auto *mainLayout = dlg.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = dlg.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
 
-    auto *mSieveInfoWidget = dlg.findChild<KSieveUi::SieveInfoWidget *>(QStringLiteral("mSieveInfoWidget"));
+    auto mSieveInfoWidget = dlg.findChild<KSieveUi::SieveInfoWidget *>(QStringLiteral("mSieveInfoWidget"));
     QVERIFY(mSieveInfoWidget);
 
-    auto *button = dlg.findChild<QDialogButtonBox *>(QStringLiteral("button"));
+    auto button = dlg.findChild<QDialogButtonBox *>(QStringLiteral("button"));
     QVERIFY(button);
 }
