@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -7,11 +7,12 @@
 #define KSIEVE_KSIEVEUI_SIEVETEXTEDIT_H
 
 #include "ksieveui_export.h"
-
 #include <KPIMTextEdit/PlainTextEditor>
+#include <memory>
 
 class QMenu;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveTextEditPrivate;
 /**
  * @brief The SieveTextEdit class
@@ -40,6 +41,7 @@ public:
     void reverseCase();
     void wordWrap(bool state);
     Q_REQUIRED_RESULT bool isWordWrap() const;
+
 protected:
     void initCompleter();
     void keyPressEvent(QKeyEvent *e) override;
@@ -67,7 +69,7 @@ private:
     void setCompleterList(const QStringList &list);
     Q_REQUIRED_RESULT QString selectedWord(const QPoint &pos = QPoint()) const;
 
-    SieveTextEditPrivate *const d;
+    std::unique_ptr<SieveTextEditPrivate> const d;
 };
 }
 #endif
