@@ -1,35 +1,34 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "managesievescriptsdialog.h"
+#include "editor/sieveeditor.h"
+#include "editor/sievetextedit.h"
+#include "managescriptsjob/checkscriptjob.h"
 #include "widgets/custommanagesievewidget.h"
 #include "widgets/managesievetreeview.h"
-#include "editor/sievetextedit.h"
-#include "editor/sieveeditor.h"
 #include "widgets/sievetreewidgetitem.h"
-#include "managescriptsjob/checkscriptjob.h"
 
 #include "util/sieveimapaccountsettings.h"
 
-#include <KLocalizedString>
-#include <QPushButton>
-#include <KMessageBox>
 #include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <QPushButton>
 
-#include <kmanagesieve/sievejob.h>
 #include "libksieve_debug.h"
+#include <kmanagesieve/sievejob.h>
 
-#include <QApplication>
 #include <QTreeWidget>
 #include <QVBoxLayout>
 
-#include <errno.h>
-#include <KSharedConfig>
 #include <KGuiItem>
+#include <KSharedConfig>
 #include <KStandardGuiItem>
+#include <errno.h>
 
 using namespace KSieveUi;
 
@@ -37,8 +36,6 @@ class KSieveUi::ManageSieveScriptsDialogPrivate
 {
 public:
     ManageSieveScriptsDialogPrivate()
-        : mIsNewScript(false)
-        , mWasActive(false)
     {
     }
 
@@ -55,8 +52,8 @@ public:
     QPushButton *mDeleteScript = nullptr;
     QPushButton *mDeactivateScript = nullptr;
 
-    bool mIsNewScript : 1;
-    bool mWasActive : 1;
+    bool mIsNewScript = false;
+    bool mWasActive = false;
 };
 
 ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *passwordProvider, QWidget *parent)
@@ -67,10 +64,10 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
     setModal(false);
     setAttribute(Qt::WA_GroupLeader);
     setAttribute(Qt::WA_DeleteOnClose);
-    auto *mainLayout = new QVBoxLayout(this);
-    QFrame *frame = new QFrame;
+    auto mainLayout = new QVBoxLayout(this);
+    auto frame = new QFrame;
     mainLayout->addWidget(frame);
-    auto *vlay = new QVBoxLayout(frame);
+    auto vlay = new QVBoxLayout(frame);
     vlay->setSpacing(0);
     vlay->setContentsMargins({});
 
@@ -80,7 +77,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
     connect(d->mTreeView, &CustomManageSieveWidget::updateButtons, this, &ManageSieveScriptsDialog::slotUpdateButtons);
     vlay->addWidget(d->mTreeView);
 
-    auto *buttonLayout = new QHBoxLayout;
+    auto buttonLayout = new QHBoxLayout;
     vlay->addLayout(buttonLayout);
 
     d->mNewScript = new QPushButton(i18nc("create a new sieve script", "New..."));
@@ -99,7 +96,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
     connect(d->mDeactivateScript, &QPushButton::clicked, d->mTreeView, &CustomManageSieveWidget::slotDeactivateScript);
     buttonLayout->addWidget(d->mDeactivateScript);
 
-    auto *close = new QPushButton;
+    auto close = new QPushButton;
     KGuiItem::assign(close, KStandardGuiItem::close());
     connect(close, &QPushButton::clicked, this, &ManageSieveScriptsDialog::accept);
     buttonLayout->addWidget(close);
@@ -111,8 +108,6 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
     } else {
         resize(sizeHint().width(), sizeHint().height());
     }
-
-    d->mTreeView->slotRefresh();
 }
 
 ManageSieveScriptsDialog::~ManageSieveScriptsDialog()
@@ -122,7 +117,6 @@ ManageSieveScriptsDialog::~ManageSieveScriptsDialog()
     group.writeEntry("Size", size());
     // prevent QTreeWidget signals triggered by it's destructor from calling our slots
     d->mTreeView->disconnect(this);
-    delete d;
 }
 
 void ManageSieveScriptsDialog::hideEvent(QHideEvent *event)
@@ -134,7 +128,7 @@ void ManageSieveScriptsDialog::hideEvent(QHideEvent *event)
 
 void ManageSieveScriptsDialog::slotUpdateButtons(QTreeWidgetItem *item)
 {
-    Q_UNUSED(item);
+    Q_UNUSED(item)
     bool newScriptAction;
     bool editScriptAction;
     bool deleteScriptAction;
@@ -170,8 +164,11 @@ void ManageSieveScriptsDialog::slotNewScript(const ManageSieveWidget::ScriptInfo
 void ManageSieveScriptsDialog::slotGetResult(KManageSieve::SieveJob *job, bool success, const QString &script, bool isActive)
 {
     if (!success) {
-        KMessageBox::error(this, i18n("Retrieving the script failed.\n"
-                                      "The server responded:\n%1", job->errorString()), i18n("Sieve Error"));
+        KMessageBox::error(this,
+                           i18n("Retrieving the script failed.\n"
+                                "The server responded:\n%1",
+                                job->errorString()),
+                           i18n("Sieve Error"));
         return;
     }
 
@@ -205,7 +202,7 @@ void ManageSieveScriptsDialog::slotSieveEditorCheckSyntaxClicked()
         return;
     }
     d->mSieveEditor->addNormalMessage(i18n("Uploading script to server for checking it, please wait..."));
-    auto *checkScriptJob = new KSieveUi::CheckScriptJob(this);
+    auto checkScriptJob = new KSieveUi::CheckScriptJob(this);
     connect(checkScriptJob, &CheckScriptJob::finished, this, &ManageSieveScriptsDialog::slotCheckScriptFinished);
     checkScriptJob->setIsActive(d->mWasActive);
     checkScriptJob->setOriginalScript(d->mSieveEditor->originalScript());
@@ -250,15 +247,17 @@ void ManageSieveScriptsDialog::slotCheckScriptFinished(const QString &errorMsg,
 void ManageSieveScriptsDialog::slotPutResult(KManageSieve::SieveJob *job, bool success)
 {
     if (success) {
-        KMessageBox::information(this, i18n("The Sieve script was successfully uploaded."),
-                                 i18n("Sieve Script Upload"));
+        KMessageBox::information(this, i18n("The Sieve script was successfully uploaded."), i18n("Sieve Script Upload"));
         d->mSieveEditor->deleteLater();
         d->mSieveEditor = nullptr;
         d->mCurrentURL = QUrl();
     } else {
-        //Don't add parent otherwise when there is an error it will parent to ManageSieveScriptsDialog and not editor
-        KMessageBox::error(nullptr, i18n("Uploading the Sieve script failed.\n"
-                                         "The server responded:\n%1", job->errorString()), i18n("Sieve Error"));
+        // Don't add parent otherwise when there is an error it will parent to ManageSieveScriptsDialog and not editor
+        KMessageBox::error(nullptr,
+                           i18n("Uploading the Sieve script failed.\n"
+                                "The server responded:\n%1",
+                                job->errorString()),
+                           i18n("Sieve Error"));
         if (d->mSieveEditor) {
             d->mSieveEditor->show();
         }
