@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,15 +7,16 @@
 #ifndef SIEVESCRIPTDEBUGGERWARNING_H
 #define SIEVESCRIPTDEBUGGERWARNING_H
 
-#include <KMessageWidget>
 #include "ksieveui_private_export.h"
-namespace KSieveUi {
+#include <KMessageWidget>
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT SieveScriptDebuggerWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
     explicit SieveScriptDebuggerWarning(QWidget *parent = nullptr);
-    ~SieveScriptDebuggerWarning();
+    ~SieveScriptDebuggerWarning() override;
 
     void setErrorMessage(const QString &msg);
     void setWarningMessage(const QString &msg);
