@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,14 +12,15 @@
 class QLineEdit;
 class QPushButton;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveTextEditWidget;
 class SieveTemplateEditDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit SieveTemplateEditDialog(QWidget *parent = nullptr, bool defaultTemplate = false);
-    ~SieveTemplateEditDialog();
+    ~SieveTemplateEditDialog() override;
 
     void setTemplateName(const QString &name);
     Q_REQUIRED_RESULT QString templateName() const;
